Crate strixonomy_reasoner

Crate strixonomy_reasoner 

OntoLogos-backed reasoner facade for Strixonomy (v0.9).

Published as strixonomy-reasoner.

Structs

ClassificationResult
ConsistencyDetail
Full consistency semantics (TBox unsat + ABox / ontology consistency).
ConsistencyResult
DlQueryResult
ExplanationRequest
ExplanationResult
ExplanationStep
InferredAssertions
InferredClassAssertion
InferredHierarchy
InferredObjectPropertyAssertion
InstanceCheckResult
RealizationEntry
RealizationResult
ReasonerCache
ReasonerCacheStore
ReasonerInput
ReasonerSnapshot
ReasonerWarning
SameAsCluster
WorkspaceInputLoader

Enums

DlQueryMode
ReasonerError
ReasonerId
ReasonerProfile

Constants

DL_QUERY_CLASS_IRI
Temporary named class used to materialize anonymous Manchester expressions.

Traits

ReasonerAdapter

Functions

cancel_requested
Returns true when an in-flight reasoner run should abort.
check_consistency
check_full_consistency
Full consistency: TBox unsatisfiable classes + ABox / ontology consistency via Ontologos.
check_instance
classify
classify_with_swrl
Classify with SWRL materialization when the ontology contains SWRL rules.
clear_cancel_flag
Clear the cancel flag after a reasoner run completes.
expand_named_unsatisfiable
Expand taxonomy unsatisfiable IRIs to named classes that are ⊑ ⊥.
explain
explain_alternatives
inferred_assertions
inferred_assertions_from_realization
Collect inferred ABox assertions, reusing an existing realization when available.
inject_swrl_from_turtle
Parse strixonomy:swrlRule JSON literals from Turtle and push convertible rules.
input_has_swrl_rules
True when classify should take the SWRL path.
install_cancel_flag
Install a cancel flag for subsequent Ontologos operations on this thread.
ontology_has_swrl_rules
True when Ontologos already has SWRL rules on the ontology.
prepare_swrl_ontology
Clone input ontology, inject authored rules, and materialize SWRL inferences.
realize
run_dl_query
Run a Manchester class-expression DL Query against input.

Type Aliases

Result